@@ -67,6 +67,13 @@ GITDIR["python-ironic-inspector-client"]=$DEST/python-ironic-inspector-client
 GITREPO["python-ironic-inspector-client"]=${IRONIC_INSPECTOR_CLIENT_REPO:-${GIT_BASE}/openstack/python-ironic-inspector-client.git}
 GITBRANCH["python-ironic-inspector-client"]=${IRONIC_INSPECTOR_CLIENT_BRANCH:-master}
 
+# This is defined in ironic's devstack plugin. Redefine it just in case, and
+# insert "inspector" if it's missing.
+IRONIC_ENABLED_INSPECT_INTERFACES=${IRONIC_ENABLED_INSPECT_INTERFACES:-"inspector,no-inspect"}
+if [[ "$IRONIC_ENABLED_INSPECT_INTERFACES" != *inspector* ]]; then
+    IRONIC_ENABLED_INSPECT_INTERFACES="inspector,$IRONIC_ENABLED_INSPECT_INTERFACES"
+fi
+
 ### Utilities
 
 function mkdir_chown_stack {
@@ -195,7 +202,7 @@ function inspector_configure_auth_for {
     inspector_iniset $1 user_domain_id default
     inspector_iniset $1 project_domain_id default
     inspector_iniset $1 cafile $SSL_BUNDLE_FILE
-    inspector_iniset $1 os_region $REGION_NAME
+    inspector_iniset $1 region_name $REGION_NAME
 }
 
 function is_dnsmasq_filter_required {
@@ -245,7 +252,9 @@ function configure_inspector {
 
     create_service_user "$IRONIC_INSPECTOR_ADMIN_USER" "admin"
 
-    cp "$IRONIC_INSPECTOR_DIR/example.conf" "$IRONIC_INSPECTOR_CONF_FILE"
+    # start with a fresh config file
+    rm -f "$IRONIC_INSPECTOR_CONF_FILE"
+
     inspector_iniset DEFAULT debug $IRONIC_INSPECTOR_DEBUG
     inspector_configure_auth_for ironic
     configure_auth_token_middleware $IRONIC_INSPECTOR_CONF_FILE $IRONIC_INSPECTOR_ADMIN_USER $IRONIC_INSPECTOR_AUTH_CACHE_DIR/api
