@@ -17,6 +17,7 @@ from ironicclient import client
 from ironicclient import exceptions as ironic_exc
 import netaddr
 from oslo_config import cfg
+import retrying
 
 from ironic_inspector.common.i18n import _
 from ironic_inspector.common import keystone
@@ -83,6 +84,14 @@ def get_client(token=None,
                api_version=DEFAULT_IRONIC_API_VERSION):  # pragma: no cover
     """Get Ironic client instance."""
     global IRONIC_SESSION
+
+    # NOTE: To support standalone ironic without keystone
+    # TODO(pas-ha) remove handling of deprecated opts in Rocky
+    # TODO(pas-ha) rewrite when ironicclient natively supports 'none' auth
+    # via sessions https://review.openstack.org/#/c/359061/
+    if CONF.ironic.auth_strategy == 'noauth':
+        CONF.set_override('auth_type', 'none', group='ironic')
+
     if not IRONIC_SESSION:
         IRONIC_SESSION = keystone.get_session('ironic')
 
@@ -93,14 +102,8 @@ def get_client(token=None,
 
     adapter_opts = dict()
 
-    # NOTE: To support standalone ironic without keystone
-    # TODO(pas-ha) remove handling of deprecated opts in Rocky
-    # TODO(pas-ha) rewrite when ironicclient natively supports 'none' auth
-    # via sessions https://review.openstack.org/#/c/359061/
-    if CONF.ironic.auth_strategy == 'noauth':
-        CONF.set_override('auth_type', 'none', group='ironic')
-    else:
-        # TODO(pas-ha) use service auth with incoming token
+    # TODO(pas-ha) use service auth with incoming token
+    if CONF.ironic.auth_type != 'none':
         if token is None:
             args['session'] = IRONIC_SESSION
         else:
@@ -160,3 +163,16 @@ def get_node(node_id, ironic=None, **kwargs):
     except ironic_exc.HttpError as exc:
         raise utils.Error(_("Cannot get node %(node)s: %(exc)s") %
                           {'node': node_id, 'exc': exc})
+
+
+@retrying.retry(
+    retry_on_exception=lambda exc: isinstance(exc, ironic_exc.ClientException),
+    stop_max_attempt_number=5, wait_fixed=1000)
+def call_with_retries(func, *args, **kwargs):
+    """Call an ironic client function retrying all errors.
+
+    If an ironic client exception is raised, try calling the func again,
+    at most 5 times, waiting 1 sec between each call. If on the 5th attempt
+    the func raises again, the exception is propagated to the caller.
+    """
+    return func(*args, **kwargs)
