@@ -38,14 +38,18 @@ def upgrade():
         sa.Column('uuid', sa.String(36), primary_key=True),
         sa.Column('started_at', sa.Float, nullable=True),
         sa.Column('finished_at', sa.Float, nullable=True),
-        sa.Column('error', sa.Text, nullable=True)
+        sa.Column('error', sa.Text, nullable=True),
+        mysql_ENGINE='InnoDB',
+        mysql_DEFAULT_CHARSET='UTF8'
     )
 
     op.create_table(
         'attributes',
         sa.Column('name', sa.String(255), primary_key=True),
         sa.Column('value', sa.String(255), primary_key=True),
-        sa.Column('uuid', sa.String(36), sa.ForeignKey('nodes.uuid'))
+        sa.Column('uuid', sa.String(36), sa.ForeignKey('nodes.uuid')),
+        mysql_ENGINE='InnoDB',
+        mysql_DEFAULT_CHARSET='UTF8'
     )
 
     op.create_table(
@@ -53,11 +57,7 @@ def upgrade():
         sa.Column('uuid', sa.String(36), sa.ForeignKey('nodes.uuid'),
                   primary_key=True),
         sa.Column('name', sa.String(255), primary_key=True),
-        sa.Column('value', sa.Text)
+        sa.Column('value', sa.Text),
+        mysql_ENGINE='InnoDB',
+        mysql_DEFAULT_CHARSET='UTF8'
     )
-
-
-def downgrade():
-    op.drop_table('nodes')
-    op.drop_table('attributes')
-    op.drop_table('options')
